# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkSurfaceSpatialObjectPython
else:
    import _itkSurfaceSpatialObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkPointPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkSurfaceSpatialObjectPointPython
import itk.itkSpatialObjectPointPython
import itk.itkRGBAPixelPython
import itk.itkSpatialObjectBasePython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.ITKCommonBasePython
import itk.itkArrayPython
import itk.itkTransformBasePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkSpatialObjectPropertyPython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
class listitkPointBasedSpatialObjectSurface2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectSurface2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectSurface2_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectSurface2_Pointer,std::allocator< itkPointBasedSpatialObjectSurface2_Pointer > > const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectSurface2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectSurface2_Pointer,std::allocator< itkPointBasedSpatialObjectSurface2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectSurface2_Pointer > &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::allocator_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectSurface2_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectSurface2_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectSurface2_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectSurface2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectSurface2_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_swiginit(self, _itkSurfaceSpatialObjectPython.new_listitkPointBasedSpatialObjectSurface2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_reverse(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_listitkPointBasedSpatialObjectSurface2_Pointer

# Register listitkPointBasedSpatialObjectSurface2_Pointer in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface2_Pointer_swigregister(listitkPointBasedSpatialObjectSurface2_Pointer)
class listitkPointBasedSpatialObjectSurface3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkPointBasedSpatialObjectSurface3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkPointBasedSpatialObjectSurface3_Pointer

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        v: std::list< itkPointBasedSpatialObjectSurface3_Pointer,std::allocator< itkPointBasedSpatialObjectSurface3_Pointer > > const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        j: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkPointBasedSpatialObjectSurface3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkPointBasedSpatialObjectSurface3_Pointer,std::allocator< itkPointBasedSpatialObjectSurface3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::difference_type
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkPointBasedSpatialObjectSurface3_Pointer > &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::allocator_type"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator
        last: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkPointBasedSpatialObjectSurface3_Pointer
        __init__(self, other) -> listitkPointBasedSpatialObjectSurface3_Pointer

        Parameters
        ----------
        other: std::list< itkPointBasedSpatialObjectSurface3_Pointer > const &

        __init__(self, size) -> listitkPointBasedSpatialObjectSurface3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type

        __init__(self, size, value) -> listitkPointBasedSpatialObjectSurface3_Pointer

        Parameters
        ----------
        size: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type
        value: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_swiginit(self, _itkSurfaceSpatialObjectPython.new_listitkPointBasedSpatialObjectSurface3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::iterator
        n: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::size_type
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkPointBasedSpatialObjectSurface3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_reverse(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_listitkPointBasedSpatialObjectSurface3_Pointer

# Register listitkPointBasedSpatialObjectSurface3_Pointer in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.listitkPointBasedSpatialObjectSurface3_Pointer_swigregister(listitkPointBasedSpatialObjectSurface3_Pointer)
class listitkSurfaceSpatialObject2_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkSurfaceSpatialObject2_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkSurfaceSpatialObject2_Pointer

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        v: std::list< itkSurfaceSpatialObject2_Pointer,std::allocator< itkSurfaceSpatialObject2_Pointer > > const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkSurfaceSpatialObject2_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkSurfaceSpatialObject2_Pointer,std::allocator< itkSurfaceSpatialObject2_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject2_Pointer >::difference_type
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::value_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkSurfaceSpatialObject2_Pointer > &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::allocator_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkSurfaceSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject2_Pointer >::iterator

        erase(self, first, last) -> std::list< itkSurfaceSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkSurfaceSpatialObject2_Pointer >::iterator
        last: std::list< itkSurfaceSpatialObject2_Pointer >::iterator

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkSurfaceSpatialObject2_Pointer
        __init__(self, other) -> listitkSurfaceSpatialObject2_Pointer

        Parameters
        ----------
        other: std::list< itkSurfaceSpatialObject2_Pointer > const &

        __init__(self, size) -> listitkSurfaceSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkSurfaceSpatialObject2_Pointer >::size_type

        __init__(self, size, value) -> listitkSurfaceSpatialObject2_Pointer

        Parameters
        ----------
        size: std::list< itkSurfaceSpatialObject2_Pointer >::size_type
        value: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_swiginit(self, _itkSurfaceSpatialObjectPython.new_listitkSurfaceSpatialObject2_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkSurfaceSpatialObject2_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkSurfaceSpatialObject2_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkSurfaceSpatialObject2_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkSurfaceSpatialObject2_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject2_Pointer >::iterator
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject2_Pointer >::iterator
        n: std::list< itkSurfaceSpatialObject2_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject2_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_reverse(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_listitkSurfaceSpatialObject2_Pointer

# Register listitkSurfaceSpatialObject2_Pointer in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject2_Pointer_swigregister(listitkSurfaceSpatialObject2_Pointer)
class listitkSurfaceSpatialObject3_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkSurfaceSpatialObject3_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkSurfaceSpatialObject3_Pointer

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        v: std::list< itkSurfaceSpatialObject3_Pointer,std::allocator< itkSurfaceSpatialObject3_Pointer > > const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        j: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkSurfaceSpatialObject3_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkSurfaceSpatialObject3_Pointer,std::allocator< itkSurfaceSpatialObject3_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkSurfaceSpatialObject3_Pointer >::difference_type
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::value_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::size_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkSurfaceSpatialObject3_Pointer > &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::reverse_iterator"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::allocator_type"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkSurfaceSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject3_Pointer >::iterator

        erase(self, first, last) -> std::list< itkSurfaceSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkSurfaceSpatialObject3_Pointer >::iterator
        last: std::list< itkSurfaceSpatialObject3_Pointer >::iterator

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkSurfaceSpatialObject3_Pointer
        __init__(self, other) -> listitkSurfaceSpatialObject3_Pointer

        Parameters
        ----------
        other: std::list< itkSurfaceSpatialObject3_Pointer > const &

        __init__(self, size) -> listitkSurfaceSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkSurfaceSpatialObject3_Pointer >::size_type

        __init__(self, size, value) -> listitkSurfaceSpatialObject3_Pointer

        Parameters
        ----------
        size: std::list< itkSurfaceSpatialObject3_Pointer >::size_type
        value: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_swiginit(self, _itkSurfaceSpatialObjectPython.new_listitkSurfaceSpatialObject3_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkSurfaceSpatialObject3_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkSurfaceSpatialObject3_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkSurfaceSpatialObject3_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkSurfaceSpatialObject3_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject3_Pointer >::iterator
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkSurfaceSpatialObject3_Pointer >::iterator
        n: std::list< itkSurfaceSpatialObject3_Pointer >::size_type
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkSurfaceSpatialObject3_Pointer >::value_type const &

        """
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_reverse(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_listitkSurfaceSpatialObject3_Pointer

# Register listitkSurfaceSpatialObject3_Pointer in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.listitkSurfaceSpatialObject3_Pointer_swigregister(listitkSurfaceSpatialObject3_Pointer)

def itkPointBasedSpatialObjectSurface2_New():
    return itkPointBasedSpatialObjectSurface2.New()

class itkPointBasedSpatialObjectSurface2(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkPointBasedSpatialObjectSurface2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectSurface2_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectSurface2_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkSurfaceSpatialObjectPoint2 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkSurfaceSpatialObjectPoint2,std::allocator< itkSurfaceSpatialObjectPoint2 > > const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkSurfaceSpatialObjectPoint2
        GetPoints(self) -> vectoritkSurfaceSpatialObjectPoint2
        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkSurfaceSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkSurfaceSpatialObjectPoint2

        Parameters
        ----------
        id: unsigned long

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkSurfaceSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkSurfaceSpatialObjectPoint2

        Parameters
        ----------
        point: itkPointD2 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_itkPointBasedSpatialObjectSurface2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectSurface2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectSurface2

        Create a new object of the class itkPointBasedSpatialObjectSurface2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectSurface2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectSurface2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectSurface2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectSurface2 in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface2_swigregister(itkPointBasedSpatialObjectSurface2)

def itkPointBasedSpatialObjectSurface3_New():
    return itkPointBasedSpatialObjectSurface3.New()

class itkPointBasedSpatialObjectSurface3(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkPointBasedSpatialObjectSurface3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkPointBasedSpatialObjectSurface3_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkPointBasedSpatialObjectSurface3_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_Clone(self)

    def AddPoint(self, newPoint):
        r"""
        AddPoint(self, newPoint)

        Parameters
        ----------
        newPoint: itkSurfaceSpatialObjectPoint3 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_AddPoint(self, newPoint)

    def RemovePoint(self, id):
        r"""
        RemovePoint(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_RemovePoint(self, id)

    def SetPoints(self, newPoints):
        r"""
        SetPoints(self, newPoints)

        Parameters
        ----------
        newPoints: std::vector< itkSurfaceSpatialObjectPoint3,std::allocator< itkSurfaceSpatialObjectPoint3 > > const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_SetPoints(self, newPoints)

    def GetPoints(self, *args):
        r"""
        GetPoints(self) -> vectoritkSurfaceSpatialObjectPoint3
        GetPoints(self) -> vectoritkSurfaceSpatialObjectPoint3
        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_GetPoints(self, *args)

    def GetPoint(self, *args):
        r"""
        GetPoint(self, id) -> itkSurfaceSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        GetPoint(self, id) -> itkSurfaceSpatialObjectPoint3

        Parameters
        ----------
        id: unsigned long

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_GetPoint(self, *args)

    def GetNumberOfPoints(self):
        r"""GetNumberOfPoints(self) -> unsigned long"""
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_GetNumberOfPoints(self)

    def ClosestPointInWorldSpace(self, point):
        r"""
        ClosestPointInWorldSpace(self, point) -> itkSurfaceSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_ClosestPointInWorldSpace(self, point)

    def ClosestPointInObjectSpace(self, point):
        r"""
        ClosestPointInObjectSpace(self, point) -> itkSurfaceSpatialObjectPoint3

        Parameters
        ----------
        point: itkPointD3 const &

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_ClosestPointInObjectSpace(self, point)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_itkPointBasedSpatialObjectSurface3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointBasedSpatialObjectSurface3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkPointBasedSpatialObjectSurface3

        Create a new object of the class itkPointBasedSpatialObjectSurface3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkPointBasedSpatialObjectSurface3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkPointBasedSpatialObjectSurface3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkPointBasedSpatialObjectSurface3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkPointBasedSpatialObjectSurface3 in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.itkPointBasedSpatialObjectSurface3_swigregister(itkPointBasedSpatialObjectSurface3)

def itkSurfaceSpatialObject2_New():
    return itkSurfaceSpatialObject2.New()

class itkSurfaceSpatialObject2(itkPointBasedSpatialObjectSurface2):
    r"""Proxy of C++ itkSurfaceSpatialObject2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSurfaceSpatialObject2_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSurfaceSpatialObject2_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject2_Clone(self)

    def ComputeNormals(self):
        r"""ComputeNormals(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject2_ComputeNormals(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_itkSurfaceSpatialObject2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSurfaceSpatialObject2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSurfaceSpatialObject2

        Create a new object of the class itkSurfaceSpatialObject2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSurfaceSpatialObject2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSurfaceSpatialObject2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSurfaceSpatialObject2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSurfaceSpatialObject2 in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject2_swigregister(itkSurfaceSpatialObject2)

def itkSurfaceSpatialObject3_New():
    return itkSurfaceSpatialObject3.New()

class itkSurfaceSpatialObject3(itkPointBasedSpatialObjectSurface3):
    r"""Proxy of C++ itkSurfaceSpatialObject3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkSurfaceSpatialObject3_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkSurfaceSpatialObject3_Pointer"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject3_Clone(self)

    def ComputeNormals(self):
        r"""ComputeNormals(self) -> bool"""
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject3_ComputeNormals(self)
    __swig_destroy__ = _itkSurfaceSpatialObjectPython.delete_itkSurfaceSpatialObject3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSurfaceSpatialObject3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkSurfaceSpatialObject3

        Create a new object of the class itkSurfaceSpatialObject3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkSurfaceSpatialObject3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkSurfaceSpatialObject3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkSurfaceSpatialObject3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkSurfaceSpatialObject3 in _itkSurfaceSpatialObjectPython:
_itkSurfaceSpatialObjectPython.itkSurfaceSpatialObject3_swigregister(itkSurfaceSpatialObject3)

